@@ -286,23 +286,17 @@ class RepoObject:
         print(f"{self.abs_path}")
         subprocess.run(["code", self.abs_path], shell=True)
 
-class MyWindow(QWidget):
+class WCheckGUI(QWidget):
     def __init__(self, repos, config_file_path= "", config_repo=None):
-        super(MyWindow,self).__init__()
+        super(WCheckGUI,self).__init__()
         self.initUI(repos, config_file_path, config_repo)
 
-    # def refresh_repos(self):
-    #     print(f"HEER")
-
     def initUI(self, repos, config_file_path= "", config_repo=None):
         
         layout = QVBoxLayout()
         if (config_repo != None):
             layout.addWidget(QLabel(f"Configuration file: {config_file_path}"))
         repo_layout = QGridLayout()
-        # bb = QPushButton("Refresh")
-        # bb.clicked.connect(self.refresh_repos)
-        # layout.addWidget(bb)
         layout.addLayout(repo_layout)
         self.repo_objects = {}
         for repo_i, repo_name in enumerate(repos):
@@ -322,21 +316,20 @@ class MyWindow(QWidget):
                     label_config = QLabel(f"Not in config")
                     label_config.setStyleSheet("color: Gray")
                     repo_layout.addWidget(label_config, repo_i, 4)
-            # label = QLabel(f"{repo_name} - {repo_version}")
         self.setLayout(layout)
 
 def show_gui(repos, config_file_path= "", config_repo=None): 
     # Create PyQt5 application with the list of repositories
     app = QApplication(sys.argv)
-    window = MyWindow(repos, config_file_path, config_repo)
-    window.setWindowTitle("Repositories")
+    window = WCheckGUI(repos, config_file_path, config_repo)
+    window.setWindowTitle("Worspace Repositories")
     window.show()
     sys.exit(app.exec())
 
 
 def get_workspace_repos(workspace_directory):
     source_repos = {}
-    if (not os.path.isdir(workspace_directory)):
+    if (not workspace_directory.is_dir()):
         print(f"{workspace_directory} is not a directory")
         return source_repos
 
@@ -345,7 +338,7 @@ def get_workspace_repos(workspace_directory):
         for dir_in_source in dirs:
             d = Path(root) / dir_in_source
             # Check if directory is a git repository
-            if os.path.isdir(d) and os.path.exists( d / ".git"):
+            if d.is_dir() and ( d / ".git").exists():
                 source_repos[dir_in_source] = Repo(d)
     return source_repos
 
@@ -372,7 +365,6 @@ def compare_config_versions(config_filename, full=False, verbose=False, show_tim
         config_repo = Repo(config_filename, search_parent_directories=True) 
     except:
         print("Config file is not inside a git repository")
-        # sys.exit(1)
         return
 
     if (config_repo.is_dirty()):
@@ -383,11 +375,11 @@ def compare_config_versions(config_filename, full=False, verbose=False, show_tim
             config_repo.git.stash()
         else:
             return
-        # sys.exit(1)
 
 
     original_branch = config_repo.active_branch.name
-    today_datime = pendulum.now()
+    if show_time:
+        today_datime = pendulum.now()
 
     if (version_filter is not None):
         print(f"Using filter {version_filter}")
@@ -545,13 +537,13 @@ def compare_workspace_to_config(workspace_directory, config_filename, full=False
 def main():
     # Parse arguments
     parser = argparse.ArgumentParser()
-    parser.add_argument("command", help="Action to take", choices=["status", "wconfig", "config_list", "config_versions"])
-    parser.add_argument("-w", "--workspace_directory", help="Workspace directory")
+    parser.add_argument("command", help="Action to take", choices=["status", "config_workspace", "config_list", "config_versions"])
+    parser.add_argument("-w", "--workspace-directory", help="Workspace directory. Use current directory if not specified")
     parser.add_argument("-c", "--config", help="VCS Configuration file", nargs='*')
     parser.add_argument("-f","--full", action="store_true",  help="If present show all repositories, if omitted show only repositories that don't match the configuration file")
     parser.add_argument("-v","--verbose", action="store_true", help="Show more information")
     parser.add_argument("--show_time", action="store_true", help="Show last modified time")
-    parser.add_argument("--filter", default=None, help="Show last modified time", nargs='*')
+    parser.add_argument("--filter", default=None, help="List of filters for versions", nargs='*')
     parser.add_argument("--fetch", action="store_true", help="Fetch remote branches")
     parser.add_argument("--gui", action="store_true", help="Use GUI to change branches")
     parser.add_argument("--full-name", action="store_true", help="Use full filename for config table")
@@ -572,19 +564,20 @@ def main():
     show_last_modified = args.show_time
     full_name = args.full_name
     gui = args.gui
-    print(f"Options: verbose={verbose_output}, full={full}, show_last_modified={show_last_modified}")
+    if verbose_output:
+        print(f"Selected Options: verbose={verbose_output}, full={full}, show_last_modified={show_last_modified}")
 
     # Check commands
     if (command ==  "status"):
         # Check if source directory is specified
         if not args.workspace_directory:
-            print("Source directory is not specified, using current directory")
+            print("Workspace directory is not specified, using current directory")
             workspace_directory = Path(os.getcwd())
         else:
             workspace_directory = Path(args.workspace_directory)
-        print(f"Using source path {workspace_directory}")
+        print(f"Using workspace directory {workspace_directory}")
         check_workspace_status(workspace_directory, full, verbose_output, show_last_modified, fetch=fetch, gui=gui)
-    elif (command == "wconfig"):
+    elif (command == "config_workspace"):
         # Check if source directory is specified
         if not args.workspace_directory:
             print("Source directory is not specified, using current directory")
